@@ -42,6 +42,7 @@ import {
   setFolderPicker,
   setCorrelationsService,
   setPluginFunctionsHook,
+  setMegaMenuOpenHook,
 } from '@grafana/runtime';
 import {
   setGetObservablePluginComponents,
@@ -50,7 +51,7 @@ import {
   setPanelRenderer,
   setPluginPage,
 } from '@grafana/runtime/internal';
-import { loadResources as loadScenesResources } from '@grafana/scenes';
+import { loadResources as loadScenesResources, sceneUtils } from '@grafana/scenes';
 import config, { updateConfig } from 'app/core/config';
 import { getStandardTransformers } from 'app/features/transformers/standardTransformers';
 
@@ -63,7 +64,11 @@ import { useChromeHeaderHeight } from './core/components/AppChrome/TopBar/useChr
 import { LazyFolderPicker } from './core/components/NestedFolderPicker/LazyFolderPicker';
 import { getAllOptionEditors, getAllStandardFieldConfigs } from './core/components/OptionsUI/registry';
 import { PluginPage } from './core/components/Page/PluginPage';
-import { GrafanaContextType, useReturnToPreviousInternal } from './core/context/GrafanaContext';
+import {
+  GrafanaContextType,
+  useMegaMenuOpenInternal,
+  useReturnToPreviousInternal,
+} from './core/context/GrafanaContext';
 import { initializeCrashDetection } from './core/crash';
 import { NAMESPACES, GRAFANA_NAMESPACE } from './core/internationalization/constants';
 import { loadTranslations } from './core/internationalization/loadTranslations';
@@ -82,6 +87,7 @@ import { initAlerting } from './features/alerting/unified/initAlerting';
 import { initAuthConfig } from './features/auth-config';
 import { getTimeSrv } from './features/dashboard/services/TimeSrv';
 import { EmbeddedDashboardLazy } from './features/dashboard-scene/embedding/EmbeddedDashboardLazy';
+import { DashboardLevelTimeMacro } from './features/dashboard-scene/scene/DashboardLevelTimeMacro';
 import { initGrafanaLive } from './features/live';
 import { PanelDataErrorView } from './features/panel/components/PanelDataErrorView';
 import { PanelRenderer } from './features/panel/components/PanelRenderer';
@@ -130,11 +136,11 @@ export class GrafanaApp {
       window.parent.postMessage('GrafanaAppInit', '*');
       const regionalFormat = config.featureToggles.localeFormatPreference
         ? config.regionalFormat
-        : config.bootData.user.language;
+        : contextSrv.user.language;
 
       const initI18nPromise = initializeI18n(
         {
-          language: config.bootData.user.language,
+          language: contextSrv.user.language,
           ns: NAMESPACES,
           module: loadTranslations,
         },
@@ -157,7 +163,7 @@ export class GrafanaApp {
       startMeasure('frontend_app_init');
 
       setLocale(config.regionalFormat);
-      setWeekStart(config.bootData.user.weekStart);
+      setWeekStart(contextSrv.user.weekStart);
       setPanelRenderer(PanelRenderer);
       setPluginPage(PluginPage);
       setFolderPicker(LazyFolderPicker);
@@ -165,7 +171,7 @@ export class GrafanaApp {
       setLocationSrv(locationService);
       setCorrelationsService(new CorrelationsService());
       setEmbeddedDashboard(EmbeddedDashboardLazy);
-      setTimeZoneResolver(() => config.bootData.user.timezone);
+      setTimeZoneResolver(() => contextSrv.user.timezone);
       initGrafanaLive();
       setCurrentUser(contextSrv.user);
 
@@ -213,16 +219,17 @@ export class GrafanaApp {
         getPanelPluginFromCache: syncGetPanelPlugin,
       });
 
-      if (config.featureToggles.useSessionStorageForRedirection) {
-        handleRedirectTo();
-      }
-
+      // Login redirect requires locationUtil to be initialized
       locationUtil.initialize({
-        config,
+        config: window.grafanaBootData.settings,
         getTimeRangeForUrl: getTimeSrv().timeRangeForUrl,
         getVariablesUrlParams: getVariablesUrlParams,
       });
 
+      if (config.featureToggles.useSessionStorageForRedirection) {
+        handleRedirectTo();
+      }
+
       // intercept anchor clicks and forward it to custom history instead of relying on browser's history
       document.addEventListener('click', interceptLinkClicks);
 
@@ -277,12 +284,18 @@ export class GrafanaApp {
       };
 
       setReturnToPreviousHook(useReturnToPreviousInternal);
+      setMegaMenuOpenHook(useMegaMenuOpenInternal);
       setChromeHeaderHeightHook(useChromeHeaderHeight);
 
       if (config.featureToggles.crashDetection) {
         initializeCrashDetection();
       }
 
+      if (config.featureToggles.dashboardLevelTimeMacros) {
+        sceneUtils.registerVariableMacro('__from', DashboardLevelTimeMacro, true);
+        sceneUtils.registerVariableMacro('__to', DashboardLevelTimeMacro, true);
+      }
+
       const root = createRoot(document.getElementById('reactRoot')!);
       root.render(
         createElement(AppWrapper, {
@@ -359,8 +372,8 @@ async function initEchoSrv() {
         },
         buildInfo: config.buildInfo,
         user: {
-          id: String(config.bootData.user?.id),
-          email: config.bootData.user?.email,
+          id: String(contextSrv.user?.id),
+          email: contextSrv.user?.email,
         },
         ignoreUrls: rudderstackUrls,
       })
@@ -392,7 +405,7 @@ async function initEchoSrv() {
       new RudderstackBackend({
         writeKey: config.rudderstackWriteKey,
         dataPlaneUrl: config.rudderstackDataPlaneUrl,
-        user: config.bootData.user,
+        user: contextSrv.user,
         sdkUrl: config.rudderstackSdkUrl,
         configUrl: config.rudderstackConfigUrl,
         integrationsUrl: config.rudderstackIntegrationsUrl,
@@ -464,7 +477,8 @@ function handleRedirectTo(): void {
     // In this case there should be a request to the backend
     window.location.replace(decodedRedirectTo);
   } else {
-    locationService.replace(decodedRedirectTo);
+    const stripped = locationUtil.stripBaseFromUrl(decodedRedirectTo);
+    locationService.replace(stripped);
   }
 }
 
