@@ -1,6 +1,8 @@
 import { useAlertmanager } from 'app/features/alerting/unified/state/AlertmanagerContext';
 
 import { GRAFANA_RULES_SOURCE_NAME } from '../../utils/datasource';
+import { withPageErrorBoundary } from '../../withPageErrorBoundary';
+import { AlertmanagerPageWrapper } from '../AlertingPageWrapper';
 
 import { CloudReceiverForm } from './form/CloudReceiverForm';
 import { GrafanaReceiverForm } from './form/GrafanaReceiverForm';
@@ -14,4 +16,12 @@ const NewReceiverView = () => {
   }
 };
 
-export default NewReceiverView;
+function NewReceiverViewPage() {
+  return (
+    <AlertmanagerPageWrapper navId="receivers" accessType="notification">
+      <NewReceiverView />
+    </AlertmanagerPageWrapper>
+  );
+}
+
+export default withPageErrorBoundary(NewReceiverViewPage);
