@@ -1,7 +1,8 @@
 import { Observable } from 'rxjs';
+
 import { AlertStateInfo, AnnotationEvent, AnnotationQuery, DataSourceApi, TimeRange } from '@grafana/data';
 
-import { DashboardModel } from '../../../dashboard/state';
+import { DashboardModel } from '../../../dashboard/state/DashboardModel';
 
 export interface DashboardQueryRunnerOptions {
   dashboard: DashboardModel;
