@@ -1,9 +1,10 @@
 import { useCallback, useState } from 'react';
 import * as React from 'react';
 
+import { t } from '@grafana/i18n';
 import { Input } from '@grafana/ui';
 
-import { AzureQueryEditorFieldProps } from '../../types';
+import { AzureQueryEditorFieldProps } from '../../types/types';
 import { Field } from '../shared/Field';
 
 import { setTop } from './setQueryValue';
@@ -25,7 +26,7 @@ const TopField = ({ onQueryChange, query }: AzureQueryEditorFieldProps) => {
   }, [onQueryChange, query, value]);
 
   return (
-    <Field label="Top">
+    <Field label={t('components.top-field.label-top', 'Top')}>
       <Input
         id="azure-monitor-metrics-top-field"
         value={value}
