@@ -1,4 +1,4 @@
-import Map from 'ol/Map';
+import OpenLayersMap from 'ol/Map';
 import { Point } from 'ol/geom';
 import { VectorImage } from 'ol/layer';
 import LayerGroup from 'ol/layer/Group';
@@ -14,6 +14,7 @@ import {
   GrafanaTheme2,
   FrameGeometrySourceMode,
   EventBus,
+  PanelOptionsEditorBuilder,
 } from '@grafana/data';
 import { t } from '@grafana/i18n';
 import { FrameVectorSource } from 'app/features/geo/utils/frameVectorSource';
@@ -68,7 +69,7 @@ export const markersLayer: MapLayerRegistryItem<MarkersConfig> = {
    * @param options
    * @param theme
    */
-  create: async (map: Map, options: MapLayerOptions<MarkersConfig>, eventBus: EventBus, theme: GrafanaTheme2) => {
+  create: async (map: OpenLayersMap, options: MapLayerOptions<MarkersConfig>, eventBus: EventBus, theme: GrafanaTheme2) => {
     // Assert default values
     const config = {
       ...defaultOptions,
@@ -87,8 +88,7 @@ export const markersLayer: MapLayerRegistryItem<MarkersConfig> = {
     let hasVector = hasText;
 
     const layers = new LayerGroup({
-      // If text and no symbol, only show text - fall back on default symbol
-      layers: hasVector && symbol ? [symbolLayer, vectorLayer] : hasVector && !symbol ? [vectorLayer] : [symbolLayer],
+      layers: hasVector ? (symbol ? [symbolLayer, vectorLayer] : [vectorLayer]) : [symbolLayer],
     });
 
     const legendProps = new ReplaySubject<MarkersLegendProps>(1);
@@ -176,7 +176,11 @@ export const markersLayer: MapLayerRegistryItem<MarkersConfig> = {
               processedMarkers.add(markerKey);
             }
 
-            if (!isLineString) {
+            // Set style to be used by LineString
+            if (isLineString) {
+              const lineStringStyle = style.maker(values);
+              feature.setStyle(lineStringStyle);
+            } else {
               const colorString = tinycolor(theme.visualization.getColorByName(values.color)).toString();
               const colorValues = getRGBValues(colorString);
 
@@ -199,12 +203,6 @@ export const markersLayer: MapLayerRegistryItem<MarkersConfig> = {
               const textStyle = textMarker(values);
               feature.setStyle(textStyle);
             }
-
-            // Set style to be used by LineString
-            if (isLineString) {
-              const lineStringStyle = style.maker(values);
-              feature.setStyle(lineStringStyle);
-            }
           });
 
           // Update hasVector state after processing all features
@@ -213,10 +211,8 @@ export const markersLayer: MapLayerRegistryItem<MarkersConfig> = {
           // Update layer visibility based on current hasVector state
           const layersArray = layers.getLayers();
           layersArray.clear();
-          if (hasVector && symbol) {
-            layersArray.extend([symbolLayer, vectorLayer]);
-          } else if (hasVector && !symbol) {
-            layersArray.extend([vectorLayer]);
+          if (hasVector) {
+            layersArray.extend(symbol ? [symbolLayer, vectorLayer] : [vectorLayer]);
           } else {
             layersArray.extend([symbolLayer]);
           }
@@ -226,7 +222,7 @@ export const markersLayer: MapLayerRegistryItem<MarkersConfig> = {
       },
 
       // Marker overlay options
-      registerOptionsUI: (builder) => {
+      registerOptionsUI: (builder: PanelOptionsEditorBuilder<MapLayerOptions<MarkersConfig>>) => {
         builder
           .addCustomEditor({
             id: 'config.style',
