@@ -1,5 +1,6 @@
-import { Map as OpenLayersMap } from 'ol';
 import { FeatureLike } from 'ol/Feature';
+import OpenLayersMap from 'ol/Map';
+import BaseLayer from 'ol/layer/Base';
 import LayerGroup from 'ol/layer/Group';
 import WebGLPointsLayer from 'ol/layer/WebGLPoints';
 import { Subject } from 'rxjs';
@@ -14,6 +15,8 @@ import { MapLayerState } from '../types';
 
 import { getNextLayerName } from './utils';
 
+const layerStateMap = new WeakMap<BaseLayer, MapLayerState>();
+
 export const applyLayerFilter = (
   handler: MapLayerHandler<unknown>,
   options: MapLayerOptions<unknown>,
@@ -148,18 +151,16 @@ export async function initLayer(
   };
 
   panel.byName.set(UID, state);
-  // eslint-disable-next-line
-  (state.layer as any).__state = state;
+  layerStateMap.set(state.layer, state);
 
   // Pass state into WebGLPointsLayers contained in a LayerGroup
   if (layer instanceof LayerGroup) {
     layer
       .getLayers()
       .getArray()
-      .forEach((layer) => {
+      .forEach((layer: BaseLayer) => {
         if (layer instanceof WebGLPointsLayer) {
-          // eslint-disable-next-line
-          (layer as any).__state = state;
+          layerStateMap.set(layer, state);
         }
       });
   }
@@ -169,6 +170,6 @@ export async function initLayer(
   return state;
 }
 
-export const getMapLayerState = (l: any): MapLayerState => {
-  return l?.__state;
+export const getMapLayerState = (l: BaseLayer | undefined): MapLayerState | undefined => {
+  return l ? layerStateMap.get(l) : undefined;
 };
